import React, { useEffect, useState } from 'react';
import { PageContainer } from '@ant-design/pro-components';
import { Button, Card, Form, Input, message, Modal, Space, Table } from 'antd';
import { PlusCircleOutlined } from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';
import { delPushMessage, queryPushMessage } from '@/services/pushMessage';
import Edit from './edit';
import PushModal from '@/pages/PushMessageManagement/pushModal';

interface DataType {
  title: string;
  content: string;
  content_type: number;
  record_id: string;
}

const PushMessageManagement: React.FC = () => {
  const [form] = Form.useForm();
  const [editData, setEditData] = useState<object | null>({});
  const [visible, setVisible] = useState(false);
  const [searchData, setSearchData] = useState<object | null>({});
  const [loading, setLoading] = useState(false);
  const [pagination, setPagination] = useState({ total: 0, current: 1, pageSize: 10 });
  const [dataList, setDataList] = useState([]);
  const [pushVisible, setPushVisible] = useState(false);
  const [pushData, setPushData] = useState<object | null>({});

  // 获取列表内容
  const getList = () => {
    const params = {
      q: 'page',
      current: pagination.current,
      pageSize: pagination.pageSize,
    };
    queryPushMessage(params).then((res) => {
      if (res && res.code === 0) {
        setDataList(res.data.list);
        setPagination(res.data.pagination);
        setLoading(false);
      }
    });
  };

  useEffect(() => {
    // setLoading(true);
    getList();
  }, []);

  // 搜索
  const onFinish = () => {
    form.validateFields().then((data) => {
      setLoading(true);
      setSearchData(data);
    });
  };

  // 新增
  const onAdd = () => {
    setEditData(null);
    setVisible(true);
  };

  // 编辑
  const toEdit = (data: any) => {
    setEditData(data);
    setVisible(true);
  };

  // 删除
  const toDel = (record: any) => {
    Modal.confirm({
      title: '删除',
      content: `确认删除${record.name}`,
      onOk: () => {
        delPushMessage(record.record_id).then((res) => {
          if (res && res.code === 0) {
            message.success('删除成功');
            getList();
          } else {
            message.error('删除失败');
          }
        });
      },
    });
  };

  // 分页切换
  const tableChange = (page: any) => {
    setLoading(true);
    const params = {
      q: 'page',
      current: page.current,
      pageSize: page.pageSize,
      ...searchData,
    };
    queryPushMessage(params).then((res) => {
      if (res && res.code === 0) {
        setDataList(res.data.list);
        setPagination(res.data.pagination);
        setLoading(false);
      }
    });
  };

  // 编辑回调
  const handleEdit = () => {
    setVisible(false);
    setLoading(true);
    getList();
  };

  // 推送消息
  const toPush = (data: any) => {
    setPushVisible(true);
    setPushData(data);
  };

  // 推送回调
  const handlePushCallback = () => {
    setPushVisible(false);
    setLoading(true);
    getList();
  };

  const columns: ColumnsType<DataType> = [
    {
      title: '序号',
      align: 'center',
      key: 'index',
      render: (_: any, row: any, index: number) => index + 1,
    },
    {
      title: '推送标题',
      dataIndex: 'title',
      key: 'title',
      width: 250,
    },
    {
      title: '展示内容',
      dataIndex: 'content',
      key: 'content',
      width: 250,
    },
    {
      title: '消息类型',
      dataIndex: 'content_type',
      key: 'content_type',
      width: 250,
      render: (text) => <span>{{ 1: '系统消息', 2: '活动消息' }[text]}</span>,
    },
    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <Space size="middle">
          <a
            onClick={() => {
              toEdit(record);
            }}
          >
            编辑
          </a>
          <a
            onClick={() => {
              toPush(record);
            }}
          >
            推送
          </a>
          <a
            style={{ color: 'red' }}
            onClick={() => {
              toDel(record);
            }}
          >
            删除
          </a>
        </Space>
      ),
    },
  ];
  const paginationProps = {
    showSizeChanger: true,
    showQuickJumper: true,
    showTotal: (total: number) => {
      return <span> 共 {total}条 </span>;
    },
    ...pagination,
  };

  return (
    <PageContainer>
      <div>
        <Card>
          <Form form={form} layout="inline" onFinish={onFinish}>
            <Form.Item name="name" label="推送内容名称">
              <Input placeholder="请输入推送内容名称" />
            </Form.Item>
          </Form>
          <Button htmlType="button" type="primary" style={{ margin: '20px 0' }} onClick={onAdd}>
            <PlusCircleOutlined />
            新增推送
          </Button>
          <Table
            columns={columns}
            dataSource={dataList}
            rowKey={(record) => record.record_id}
            pagination={paginationProps}
            loading={loading}
            onChange={tableChange}
          />
          {visible && <Edit visible={visible} editCallback={handleEdit} params={editData} />}
          {pushVisible && (
            <PushModal visible={pushVisible} pushCallback={handlePushCallback} params={pushData} />
          )}
        </Card>
      </div>
    </PageContainer>
  );
};
export default PushMessageManagement;
